==> context-2.1.6-alpha2-sources.jar: com/flybits/context/plugins/activity/ActivityContextPluginService.java <==
package com.flybits.context.plugins.activity;

import android.app.PendingIntent;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.flybits.commons.library.logging.Logger;
import com.flybits.context.models.ContextData;
import com.flybits.context.services.FlybitsContextPluginService;
import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.location.ActivityRecognition;

import java.util.concurrent.TimeUnit;

public class ActivityContextPluginService extends FlybitsContextPluginService implements
        GoogleApiClient.ConnectionCallbacks,
        GoogleApiClient.OnConnectionFailedListener {

    private GoogleApiClient mGoogleApiClient;
    private final static String TAG_ACTIVITY_PLUGIN = "PluginActivity";
    private final static String PERMISSION_ACTIVITY_RECOGNITION = "com.google.android.gms.permission.ACTIVITY_RECOGNITION";

    @Override
    public void initialize(Bundle bundle) {
        if (mGoogleApiClient == null) {
            mGoogleApiClient = new GoogleApiClient.Builder(this)
                    .addApi(ActivityRecognition.API)
                    .addConnectionCallbacks(this)
                    .addOnConnectionFailedListener(this)
                    .build();
        }
    }

    @Override
    public String[] getRequiredPermissions() {
        return new String[]{PERMISSION_ACTIVITY_RECOGNITION};
    }

    @Override
    public boolean isSupported() {
        return true;
    }

    @Override
    public ContextData getData() {
        Logger.appendTag(TAG_ACTIVITY_PLUGIN).d("Fetching Data ... ");

        if (mGoogleApiClient != null) {
            if (!mGoogleApiClient.isConnected()) {
                mGoogleApiClient.blockingConnect(10, TimeUnit.SECONDS);
            }

            if (mGoogleApiClient.isConnected()) {
                Intent i = new Intent(getBaseContext(), DeviceRecognitionServiceIntent.class);
                PendingIntent mActivityRecongPendingIntent = PendingIntent.getService(getBaseContext(),
                        0, i, PendingIntent.FLAG_ONE_SHOT);

                ActivityRecognition.ActivityRecognitionApi.requestActivityUpdates(mGoogleApiClient, 0,
                        mActivityRecongPendingIntent);
            }
        }

        return null;
    }

    @Override
    public void onConnected(@Nullable Bundle bundle) {
        Logger.appendTag(TAG_ACTIVITY_PLUGIN).i("GoogleAPIClient: onConnected");
    }

    @Override
    public void onConnectionSuspended(int i) {
        Logger.appendTag(TAG_ACTIVITY_PLUGIN).w("GoogleAPIClient: onConnectionSuspended: " + i);
    }

    @Override
    public void onConnectionFailed(@NonNull ConnectionResult connectionResult) {
        Logger.appendTag(TAG_ACTIVITY_PLUGIN).e("GoogleAPIClient: onConnectionFailed: + " + connectionResult);
    }

    @Override
    public void onDestroy() {
        if (mGoogleApiClient != null && mGoogleApiClient.isConnected()) {
            mGoogleApiClient.disconnect();
        }
        Logger.appendTag(TAG_ACTIVITY_PLUGIN).d("Destroyed");
        super.onDestroy();
    }


}

==> context-2.6.0-alpha2-sources.jar: com/flybits/context/plugins/activity/ActivityContextPluginService.java <==
package com.flybits.context.plugins.activity;

import android.app.PendingIntent;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.flybits.commons.library.logging.Logger;
import com.flybits.context.models.ContextData;
import com.flybits.context.services.FlybitsContextPluginService;
import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.location.ActivityRecognition;

import java.util.concurrent.TimeUnit;

/***
 * @deprecated in version 2.6.0, will be removed in version 4.0.0.
 * CMNetworkManager API calls no longer work on devices running Android M and later once your app targets future Android versions ( > Android 10).
 * https://developers.google.com/android/reference/com/google/android/gms/gcm/GcmTaskService
 */
public class ActivityContextPluginService extends FlybitsContextPluginService implements
        GoogleApiClient.ConnectionCallbacks,
        GoogleApiClient.OnConnectionFailedListener {

    private GoogleApiClient mGoogleApiClient;
    private final static String TAG_ACTIVITY_PLUGIN = "PluginActivity";
    private final static String PERMISSION_ACTIVITY_RECOGNITION = "com.google.android.gms.permission.ACTIVITY_RECOGNITION";

    @Override
    public void initialize(Bundle bundle) {
        if (mGoogleApiClient == null) {
            mGoogleApiClient = new GoogleApiClient.Builder(this)
                    .addApi(ActivityRecognition.API)
                    .addConnectionCallbacks(this)
                    .addOnConnectionFailedListener(this)
                    .build();
        }
    }

    @Override
    public String[] getRequiredPermissions() {
        return new String[]{PERMISSION_ACTIVITY_RECOGNITION};
    }

    @Override
    public boolean isSupported() {
        return true;
    }

    @Override
    public ContextData getData() {
        Logger.appendTag(TAG_ACTIVITY_PLUGIN).d("Fetching Data ... ");

        if (mGoogleApiClient != null) {
            if (!mGoogleApiClient.isConnected()) {
                mGoogleApiClient.blockingConnect(10, TimeUnit.SECONDS);
            }

            if (mGoogleApiClient.isConnected()) {
                Intent i = new Intent(getBaseContext(), DeviceRecognitionServiceIntent.class);
                PendingIntent mActivityRecongPendingIntent = PendingIntent.getService(getBaseContext(),
                        0, i, PendingIntent.FLAG_ONE_SHOT);

                ActivityRecognition.ActivityRecognitionApi.requestActivityUpdates(mGoogleApiClient, 0,
                        mActivityRecongPendingIntent);
            }
        }

        return null;
    }

    @Override
    public void onConnected(@Nullable Bundle bundle) {
        Logger.appendTag(TAG_ACTIVITY_PLUGIN).i("GoogleAPIClient: onConnected");
    }

    @Override
    public void onConnectionSuspended(int i) {
        Logger.appendTag(TAG_ACTIVITY_PLUGIN).w("GoogleAPIClient: onConnectionSuspended: " + i);
    }

    @Override
    public void onConnectionFailed(@NonNull ConnectionResult connectionResult) {
        Logger.appendTag(TAG_ACTIVITY_PLUGIN).e("GoogleAPIClient: onConnectionFailed: + " + connectionResult);
    }

    @Override
    public void onDestroy() {
        if (mGoogleApiClient != null && mGoogleApiClient.isConnected()) {
            mGoogleApiClient.disconnect();
        }
        Logger.appendTag(TAG_ACTIVITY_PLUGIN).d("Destroyed");
        super.onDestroy();
    }


}
